@@ -1,6 +1,6 @@
 #include <iostream>
 
-#include <pqxx/all.h>
+#include <pqxx/pqxx>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -14,12 +14,12 @@ int main()
   try
   {
     connection C;
-    Transaction T(C, "test56");
+    transaction<> T(C, "test56");
 
     try
     {
       // This should fail:
-      T.Exec("DELIBERATELY INVALID TEST QUERY...", "invalid_query");
+      T.exec("DELIBERATELY INVALID TEST QUERY...", "invalid_query");
 
       throw logic_error("Invalid query did not throw execption!");
     }
